@@ -102,26 +102,32 @@ sub _reexport {
   Socket::More::Interface->import;
 }
 
-our $VERSION = 'v0.5.0';
+our $VERSION = 'v0.5.1';
 
 sub string_to_family;
 sub string_to_socktype;
 
+# NOTE: These constants allow for perl to optimise away the false condition
+# tests per platform
+use constant::more IS_DARWIN=> !!($^O =~ /darwin/i),
+                    IS_LINUX=> !!($^O =~ /linux/i),
+                    IS_BSD=>   !!($^O =~ /bsd/i);
 
-use constant::more PACK_FAMILY=>do {
-  if($^O =~ /darwin/){
-    "xC";
-  }
-  elsif($^O =~ /linux/) {
-      "s";
-  }
-  else {
-      "s";
-  }
-};
 
+#Network interface stuff
+#=======================
+#
+                    #
 sub sockaddr_family {
-  unpack PACK_FAMILY, $_[0];
+  if(IS_LINUX){
+    return unpack "S", $_[0];
+  }
+  if(IS_DARWIN){
+    return unpack "xC", $_[0];
+  }
+  if(IS_BSD){
+    return unpack "xC", $_[0];
+  }
 }
 
 
@@ -142,66 +148,72 @@ sub socket {
 
 
 
-#Network interface stuff
-#=======================
-#
-use constant::more PACK_SOCKADDR_UN=>do {
-  if($^O =~ /darwin/){
-      "xCA*";
-  }
-  elsif($^O =~ /linux/) {
-      "sA*";
-  }
-  else {
-      "sA*";
-  }
-};
 
 sub unpack_sockaddr_un {
-  unpack PACK_SOCKADDR_UN, substr($_[0],2);
+  my ($size, $fam, $name);
+  if(IS_LINUX){
+    ($fam,$name)=unpack "SZ[108]", $_[0];
+  }
+  if(IS_DARWIN){
+
+    ($size,$fam,$name)=unpack "CCZ[104]", $_[0];
+  }
+  if(IS_BSD){
+    ($size,$fam,$name)=unpack "CCZ[104]", $_[0];
+  }
+
+  
+  $name;
 }
 
 sub pack_sockaddr_un {
-  pack PACK_SOCKADDR_UN, AF_UNIX, $_[0];
+  #pack PACK_SOCKADDR_UN, 106, AF_UNIX, $_[0];
+  #PLATFORM eq pack PACK_SOCKADDR_UN, AF_UNIX, $_[0];
+  if(IS_LINUX){
+    return pack "SZ[108]", AF_UNIX, $_[0];
+  }
+  if(IS_DARWIN){
+    return pack "CCZ[104]", 106, AF_UNIX, $_[0];
+  }
+  if(IS_BSD){
+    return pack "CCZ[104]", 106, AF_UNIX, $_[0];
+  }
 }
 
-use constant::more PACK_SOCKADDR_IN=>do {
-  if($^O =~ /darwin/){
-      "xCna4x8";
-  }
-  elsif($^O =~ /linux/) {
-      "sna4x8";
-  }
-  else {
-      "sna4x8";
-  }
-};
 
 
 sub pack_sockaddr_in {
-  pack PACK_SOCKADDR_IN, AF_INET, $_[0], $_[1];
+  #pack PACK_SOCKADDR_IN, AF_INET, $_[0], $_[1];
+  if(IS_LINUX){
+    return pack "Sna4x8", AF_INET, $_[0], $_[1];
+  }
+  if(IS_DARWIN){
+    return pack "xCna4x8", AF_INET, $_[0], $_[1];
+  }
+  if(IS_BSD){
+    return pack "xCna4x8", AF_INET, $_[0], $_[1];
+  }
 }
 
 sub unpack_sockaddr_in {
-  my ($port, $addr)=unpack "na4", substr($_[0], 2);
-  ($port,$addr);
+  #my ($port, $addr)=
+  unpack "na4", substr($_[0], 2);
+  #($port,$addr);
 }
 
 
-use constant::more PACK_SOCKADDR_IN6=>do {
-  if($^O =~ /darwin/){
-   "xCnNa16N"
-  }
-  elsif($^O =~ /linux/) {
-      "snNa16N";
-  }
-  else {
-      "snNa16N";
-  }
-};
 
 sub pack_sockaddr_in6 {
-  pack PACK_SOCKADDR_IN6,  AF_INET6, $_[0], $_[3]//0, $_[1], $_[2]//0;
+  #pack PACK_SOCKADDR_IN6,  AF_INET6, $_[0], $_[3]//0, $_[1], $_[2]//0;
+  if(IS_LINUX){
+    return pack  "snNa16N",  AF_INET6, $_[0], $_[3]//0, $_[1], $_[2]//0;
+  }
+  if(IS_DARWIN){
+    return pack  "xCnNa16N",  AF_INET6, $_[0], $_[3]//0, $_[1], $_[2]//0;
+  }
+  if(IS_BSD){
+    return pack  "xCnNa16N",  AF_INET6, $_[0], $_[3]//0, $_[1], $_[2]//0;
+  }
 }
 
 sub unpack_sockaddr_in6{
@@ -339,13 +351,13 @@ sub sockaddr_passive{
 	#Check for special cases here and adjust accordingly
 	my @new_address;
 	my @new_interfaces;
-	my @new_spec_int;
+	##my @new_spec_int;
 	my @new_fam;
 
   # IF IPV4_ANY or IPV6_ANY is specified,  nuke any other address provided
   #
 	if(grep /${\IPV4_ANY()}/, @$address){
-		push @new_spec_int, IPV4_ANY;
+		#push @new_spec_int, IPV4_ANY;
 		push @new_address, IPV4_ANY;
 		push @new_fam, AF_INET;
     my @results;
@@ -356,11 +368,12 @@ sub sockaddr_passive{
       @results
     );
 
+
 		push @new_interfaces, ({name=>IPV4_ANY,addr=>$results[0]{addr}});
 	}
 
 	if(grep /${\IPV6_ANY()}/, @$address){
-		push @new_spec_int, IPV6_ANY;
+		#push @new_spec_int, IPV6_ANY;
 		push @new_address, IPV6_ANY;
     push @new_fam, AF_INET6;
     my @results;
@@ -373,6 +386,7 @@ sub sockaddr_passive{
     push @new_interfaces, ({name=>IPV6_ANY, addr=>$results[0]{addr}});
 	}
 
+
   # TODO: Also add special case for multicast interfaces? for datagrams?
 
 	if(@new_address){
